@@ -455,8 +455,10 @@ def recursive_diff(
         # Compare unordered
         for key in set(list(old) + list(new)):
             if key in ignore_keys:
-                del ret_old[key]
-                del ret_new[key]
+                if key in ret_old:
+                    del ret_old[key]
+                if key in ret_new:
+                    del ret_new[key]
             elif key in old and key in new:
                 res = recursive_diff(
                     old[key],
